==> manuskript_0.14.0.orig.tar.gz: manuskript-0.14.0/README.md <==
# Manuskript

[Manuskript](http://www.theologeek.ch/manuskript) is an open-source
tool for writers.

[![manuskript](https://snapcraft.io/manuskript/badge.svg)](https://snapcraft.io/manuskript)

Manuskript runs on GNU/Linux, Mac OS X, and Windows.

![Main view](http://www.theologeek.ch/manuskript/wp-content/uploads/2017/11/manuskript-0.5.0-main-view.jpg)

## Features

Manuskript provides a rich environment to help writers create their
first draft and then further refine and edit their masterpiece.  
With Manuskript you can:

* Grow your premise from one sentence, to a paragraph, to a full
  summary
* Create characters
* Conceive plots
* Construct outlines
  ([Outline mode](http://www.theologeek.ch/manuskript/2016/02/05/outliner/)
  and/or
  [Index cards](http://www.theologeek.ch/manuskript/2016/02/05/index-cards/))
* Write with focus
  ([Distraction free mode](https://github.com/olivierkes/manuskript/wiki/Full-screen-mode))
* Build worlds
* [Track items](https://github.com/olivierkes/manuskript/wiki/How-to-keep-track-of-important-items)
* Edit and re-organize chapters and scenes
* View [Story line](http://www.theologeek.ch/manuskript/2016/02/28/story-line/)
* Compose with
  [fiction or non-fiction templates and writing modes](http://www.theologeek.ch/manuskript/2016/03/31/writing-modes-simple-fiction/)
* Import and export document formats such as HTML, ePub, OpenDocument, DocX, and
  [more](https://github.com/olivierkes/manuskript/wiki/Import-and-Export-capabilities)


Additionally Manuskript can help in many more ways with a spell
checker, markdown highlighter,
[frequency analyzer](http://www.theologeek.ch/manuskript/2016/02/08/frequency-analyzer/),
and automatic save in
[open and plain text file format](http://www.theologeek.ch/manuskript/2016/03/31/open-plain-text-file-format/).

## Download

[Download](http://www.theologeek.ch/manuskript/download) and install Manuskript today.

## HowTo's

See the [Wiki](http://github.com/olivierkes/manuskript/wiki) for more
detailed instructions on how to install and use Manuskript.

## Contribute

You can help improve Manuskript by reporting
[issues](https://github.com/olivierkes/manuskript/issues), writing
[wiki documentation](https://github.com/olivierkes/manuskript/wiki),
and
[translating to other languages](https://github.com/olivierkes/manuskript/wiki/Translate-Manuskript).
See also
[Manuskript Contribute page](http://www.theologeek.ch/manuskript/contribute/).

Manuskript is written in Python3 and PyQt5.

## Free Software

Manuskript is [Free Software](https://www.gnu.org/philosophy/free-sw.html).  
You have the freedom to run, copy, distribute, study, change and improve the software.  
Manuskript is distributed under the [GNU General Public License](https://www.gnu.org/licenses/gpl.html) version 3 or (at your option) any later version.

==> manuskript_0.15.0.orig.tar.gz: manuskript-0.15.0/README.md <==
# Manuskript

[Manuskript](https://www.theologeek.ch/manuskript) is an open-source
tool for writers.

[![manuskript](https://snapcraft.io/manuskript/badge.svg)](https://snapcraft.io/manuskript)
[![translations](https://hosted.weblate.org/widgets/manuskript/-/translations/svg-badge.svg)](https://hosted.weblate.org/projects/manuskript/translations)

Manuskript runs on GNU/Linux, Mac OS X, and Windows.

![Main view](https://www.theologeek.ch/manuskript/wp-content/uploads/2017/11/manuskript-0.5.0-main-view.jpg)

## Features

Manuskript provides a rich environment to help writers create their
first draft and then further refine and edit their masterpiece.  
With Manuskript you can:

* Grow your premise from one sentence, to a paragraph, to a full
  summary
* Create characters
* Conceive plots
* Construct outlines
  ([Outline mode](https://www.theologeek.ch/manuskript/2016/02/05/outliner/)
  and/or
  [Index cards](https://www.theologeek.ch/manuskript/2016/02/05/index-cards/))
* Write with focus
  ([Distraction free mode](https://github.com/olivierkes/manuskript/wiki/Full-screen-mode))
* Build worlds
* [Track items](https://github.com/olivierkes/manuskript/wiki/How-to-keep-track-of-important-items)
* Edit and re-organize chapters and scenes
* View [Story line](https://www.theologeek.ch/manuskript/2016/02/28/story-line/)
* Compose with
  [fiction or non-fiction templates and writing modes](https://www.theologeek.ch/manuskript/2016/03/31/writing-modes-simple-fiction/)
* Import and export document formats such as HTML, ePub, OpenDocument, DocX, and
  [more](https://github.com/olivierkes/manuskript/wiki/Import-and-Export-capabilities)


Additionally Manuskript can help in many more ways with a spell
checker, markdown highlighter,
[frequency analyzer](https://www.theologeek.ch/manuskript/2016/02/08/frequency-analyzer/),
and automatic save in
[open and plain text file format](https://www.theologeek.ch/manuskript/2016/03/31/open-plain-text-file-format/).

## Download

[Download](https://www.theologeek.ch/manuskript/download) and install Manuskript today.

## HowTo's

See the [Wiki](https://github.com/olivierkes/manuskript/wiki) for more
detailed instructions on how to install and use Manuskript.

## Contribute

You can help improve Manuskript by reporting
[issues](https://github.com/olivierkes/manuskript/issues), writing
[wiki documentation](https://github.com/olivierkes/manuskript/wiki),
and
[translating to other languages](https://github.com/olivierkes/manuskript/wiki/Translate-Manuskript).
See also
[Manuskript Contribute page](https://www.theologeek.ch/manuskript/contribute/).

Manuskript is written in Python3 and PyQt5.

## Free Software

Manuskript is [Free Software](https://www.gnu.org/philosophy/free-sw.html).  
You have the freedom to run, copy, distribute, study, change and improve the software.  
Manuskript is distributed under the [GNU General Public License](https://www.gnu.org/licenses/gpl.html) version 3 or (at your option) any later version.
